==> scorched3d_38.1.orig.tar.gz: scorched3d-38.1/src/sprites/MissileActionRenderer.h <==
////////////////////////////////////////////////////////////////////////////////
//    Scorched3D (c) 2000-2003
//
//    This file is part of Scorched3D.
//
//    Scorched3D is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    Scorched3D is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with Scorched3D; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////////

#if !defined(__INCLUDE_MissileActionRendererh_INCLUDE__)
#define __INCLUDE_MissileActionRendererh_INCLUDE__

#include <engine/Action.h>
#include <engine/ParticleEmitter.h>
#include <tankgraph/MissileMesh.h>
#include <landscape/Smoke.h>
#include <string>
#include <map>

class MissileActionRenderer : public ActionRenderer
{
public:
	MissileActionRenderer(int flareType, float scale = 1.0f);
	virtual ~MissileActionRenderer();

	virtual void simulate(Action *action, float timepassed, bool &remove);
	virtual void draw(Action *action);

protected:
	int flareType_;
	SmokeCounter counter_;
	ParticleEmitter *flameemitter_;
	ParticleEmitter *smokeemitter_;
	MissileMesh *mesh_;
	float rotation_;
	float scale_;

};

#endif

==> scorched3d_41.3dfsg.orig.tar.gz: scorched3d-41.3dfsg/src/sprites/MissileActionRenderer.h <==
////////////////////////////////////////////////////////////////////////////////
//    Scorched3D (c) 2000-2003
//
//    This file is part of Scorched3D.
//
//    Scorched3D is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    Scorched3D is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with Scorched3D; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////////

#if !defined(__INCLUDE_MissileActionRendererh_INCLUDE__)
#define __INCLUDE_MissileActionRendererh_INCLUDE__

#include <engine/Action.h>
#include <graph/ParticleEmitter.h>
#include <tankgraph/MissileMesh.h>
#include <common/Counter.h>
#include <string>
#include <map>

class VirtualSoundSource;
class MissileActionRenderer : public ActionRenderer
{
public:
	MissileActionRenderer(int flareType, float scale = 1.0f, float spinspeed = 1.0f);
	virtual ~MissileActionRenderer();

	virtual void simulate(Action *action, float timepassed, bool &remove);
	virtual void draw(Action *action);

protected:
	int flareType_;
	VirtualSoundSource *sound_;
	Counter counter_;
	ParticleEmitter *flameemitter_;
	ParticleEmitter *smokeemitter_;
	MissileMesh *mesh_;
	float rotation_;
	float scale_;
	float frame_;
	float spinSpeed_;
};

#endif
